..
    GeoBbox documentation master file, created by
    sphinx-quickstart on Wed Jun 12 20:59:36 2024.
    You can adapt this file completely to your liking, but it should at least
    contain the root `toctree` directive.

Welcome to GeoBbox's documentation!
====================================

**GeoBbox** is a simple Python library to manipulate georeferenced bounding boxes.
It integrates with popular GIS libraries (`gee`, `folium`, `rasterio`). 

.. note::

    This project is still new and under active development. The API may break in the future.

.. toctree::
    :maxdepth: 1

    installation
    api

API
===

.. autosummary::

    geobbox


Indices and tables
==================

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
